(str-escaping-input-stream is)Given an InputStream to read a string, return an InputStream that will escape the string as it is being read.
Given an InputStream to read a string, return an InputStream that will escape the string as it is being read.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |